@@ -404,14 +404,16 @@ class PageKde(PageBase):
             self.combobox.currentIndexChanged[str].connect(
                 self.on_language_selection_changed)
             if not self.controller.oem_config:
-                self.page.oem_id_label.hide()
-                self.page.oem_id_entry.hide()
+                self.page.oem_widget.hide()
 
             def init_big_button(button, image_name):
                 pix = QPixmap('/usr/share/ubiquity/qt/images/' + image_name)
                 icon = QIcon(pix)
                 button.setIcon(icon)
                 button.setIconSize(pix.size())
+                # Set a fixed height to ensure the button text is not cropped
+                # when the window is resized
+                button.setFixedHeight(button.sizeHint().height())
 
             def inst(*args):
                 self.page.try_ubuntu.setEnabled(False)
@@ -495,12 +497,19 @@ class PageKde(PageBase):
     def openURL(self, url):
         from PyQt4.QtGui import QDesktopServices
         from PyQt4.QtCore import QUrl
-        from ubiquity.misc import drop_privileges_save, regain_privileges_save
+        import shutil
+        import os
 
         # this nonsense is needed because kde doesn't want to be root
-        drop_privileges_save()
+        misc.drop_privileges()
+        misc.drop_privileges_save()
+        # copy over gtkrc-2.0 to get the themeing right
+        if os.direxists("/usr/share/kubuntu-default-settings"):
+            shutil.copy("/usr/share/kubuntu-default-settings",
+                        os.getenv("HOME") + "./.gtkrc-2.0")
         QDesktopServices.openUrl(QUrl(url))
-        regain_privileges_save()
+        misc.regain_privileges()
+        misc.regain_privileges_save()
 
     def set_language_choices(self, choices, choice_map):
         PageBase.set_language_choices(self, choices, choice_map)
